require('dotenv').config()  // 读取系统环境变量

// HTTP 请求路由
const app = require('express')()
app.get('/', (req, res) => res.sendStatus(200))

// 服务器启动
const port = process.env.PORT || 3000
const host = process.env.HOST || 'localhost'
const server = app.listen(port, host, () => {
    console.log(`rpi sense hat server is running at http://${host}:${port}`)
})

// Sense HAT 全局数据 及 初始化
const R = [255, 0, 0]
const G = [0, 255, 0]
const B = [0, 0, 255]
const Y = [255, 255, 0]
const P = [255, 0, 255]
const C = [0, 255, 255]
const O = [255, 255, 255]
const _ = [0, 0, 0]
const sensehat = {
    led: {
        ...require('sense-hat-led').sync,
        /*
            sleep(n) 暂停 n 秒
            clear()  清除所有
            clear(rgb) or clear([r,g,b])  填充颜色
            setPixel(x,y,r,g,b) or setPixel(x,y,rgb)  设置一个点
            getPixel(x,y) 返回 [r,g,b]  获取一个点
            setPixels([[r,g,b]*64])
            getPixels() -> [[r,g,b]*64]

            flipH(redraw=true)  水平反转
            flipV(redraw=true)  垂直反转

            setRotation(r, redraw=true)  设置旋转，r 初始为 0，r 只能设置为 0/90/180/270
            getter and setter rotation 默认为 0

            getter and setter lowLight 默认为 true
            getter and setter gamma = Array of length 32 containing Integers between 0 and 31
            gammaReset()  恢复默认 gamma

            loadImage(filePath, redraw=true)

            showLetter(character, textColour=[255,255,255], backColour=[0,0,0])
            showMessage(textString, scrollSpeed=0.1(秒), textColour=[255,255,255], backColour=[0,0,0])
            flashMessage(textString, speed=0.1(秒), textColour=[255,255,255], backColour=[0,0,0])
        */
        get pixels() { return sensehat.led.getPixels() },
    },
}
sensehat.led.clear()
sensehat.led.loadImage('images/heart.png')

// socketio 服务
const io = require('socket.io')(server, { cors: { origin: '*' } })
io.on('connection', (client) => {
    client.on('action', ({ action, x, y, color, pixels, delay }) => {
        switch (action) {
            case 'clear':
                if (color == undefined) color = [0, 0, 0]
                sensehat.led.clear(color)
                break
            case 'flash':
                if (color == undefined) color = [255, 255, 255]
                sensehat.led.clear(color)
                setTimeout(sensehat.led.clear, delay | 200)
                break
            case 'setPixel':
                if (color == undefined) color = [255, 255, 255]
                sensehat.led.setPixel(Number(x), Number(y), color)
                break
            case 'getPixel':
                color = sensehat.led.getPixel(Number(x), Number(y))
                client.emit('setPixel', color)
                break
            // case 'on':
            //     sense.setPixel(Number(x), Number(y), color_blue)
            //     leds[y][x] = 1
            //     break
            // case 'off':
            //     sense.setPixel(Number(x), Number(y), [0, 0, 0])
            //     leds[y][x] = 0
            //     break
            // case 'hello':
            //     sense.flashMessage('HELLO', 1, color_blue)
            //     sense.clear()
            //     read_all_leds(0)
            //     break

            default:
                console.log('okokokokok')
                break
        }

    })
})

// io.on('connection', (client) => {
//     client.emit('leds', leds)
//     client.on('action', ({ action, x, y }) => {
//         console.log({ action, x, y })
// switch (action) {
//     case 'on':
//         sense.setPixel(Number(x), Number(y), color_blue)
//         leds[y][x] = 1
//         break
//     case 'off':
//         sense.setPixel(Number(x), Number(y), [0, 0, 0])
//         leds[y][x] = 0
//         break
//     case 'hello':
//         sense.flashMessage('HELLO', 1, color_blue)
//         sense.clear()
//         read_all_leds(0)
//         break
//     case 'flash':
//         sense.clear([255, 255, 255])
//         setTimeout(sense.clear, 100)
//         read_all_leds(0)
//         break
//     case 'clear':
//         sense.clear()
//         read_all_leds(0)
//         break
//     case 'temp':
//         read_all_leds()
//         get_rpis_info()
//         break
//     default:
//         break
// }
//         io.emit('leds', leds)
//     })
// })

// function read_all_leds(value = null) {
//     const pixels = sense.getPixels()
//     for (let y = 0; y < 8; y++) {
//         for (let x = 0; x < 8; x++) {
//             leds[y][x] = value !== null ? value : sense.getPixel(x, y)[2] == 0 ? 0 : 1
//         }
//     }
// }
